===========================
Avocado Contributor's Guide
===========================

Useful pointers on how to participate of the Avocado community and contribute.

.. toctree::
   :maxdepth: 2

   chapters/introduction
   chapters/how
   chapters/environment
   chapters/styleguides
   chapters/plugins
   chapters/runners
   chapters/results
   chapters/rfc
   chapters/releasing
   chapters/tips
   chapters/contact
